@@ -337,9 +337,9 @@ def get_genotypes(
                     metadata_quasar_input_paths_se = pool.starmap(
                         partial(
                             prepare_quasar_input_from_metadata,
-                            **prepare_quasar_input_params(temp_dir_name, len(meta_se[0]), pe=False)
+                            **prepare_quasar_input_params(temp_dir_name, len(meta_se), pe=False)
                         ),
-                        meta_se[0]
+                        meta_se
                     )
                 else:
                     metadata_quasar_input_paths_se = []
@@ -347,9 +347,9 @@ def get_genotypes(
                     metadata_quasar_input_paths_pe = pool.starmap(
                         partial(
                             prepare_quasar_input_from_metadata,
-                            **prepare_quasar_input_params(temp_dir_name, len(meta_pe[0]), pe=True)
+                            **prepare_quasar_input_params(temp_dir_name, len(meta_pe), pe=True)
                         ),
-                        meta_pe[0]
+                        meta_pe
                     )
                 else:
                     metadata_quasar_input_paths_pe = []
